@@ -2,17 +2,22 @@ import itertools
 from functools import cached_property
 from typing import Generator, Self
 
-import metrohash
 import pinecone
 from langchain import LLMChain, OpenAI, PromptTemplate
 from langchain.docstore.document import Document
 from langchain.embeddings import OpenAIEmbeddings
+from openai.error import RateLimitError
+from retry import retry
 
 from summ.cache.cacher import CacheDocument, CacheItem
 from summ.shared.utils import dedent
 
 
 class Embedding(CacheItem):
+    """A serializable embedding vector, representing a query.
+
+    Always has an associated fact."""
+
     document: CacheDocument
     query: str
     fact: str
@@ -24,8 +29,17 @@ class Embedding(CacheItem):
 
 
 class Embedder:
+    """Embedders are responsible for taking fully-populated Documents and embedding them,
+    optionally persiting them to a vector store in the process.
+
+    Currently, only Pinecone is supported.
+    """
+
     GPT3_DIMS = 1536
+
     QUERIES = 1
+    """The number of extra queries to generate per fact."""
+
     QUERY_TEMPLATE = PromptTemplate(
         input_variables=["fact", "context"],
         template=dedent(
@@ -40,13 +54,30 @@ class Embedder:
     )
 
     def create_index(self):
+        """Creates the named index in Pinecone."""
+
         pinecone.create_index(
             self.index_name,
             dimension=self.dims,
             metadata_config={"indexed": ["classes"]},
         )
 
+    def has_index(self):
+        """Checks if the named index in Pinecone exists."""
+
+        try:
+            pinecone.describe_index(self.index_name)
+            return True
+        except pinecone.exceptions.NotFoundException:
+            return False
+
     def __init__(self, index: str, dims: int = GPT3_DIMS):
+        """Creates a new Embedder.
+
+        Args:
+            index: The name of the vector db index to use.
+            dims: The number of dimensions of the vector db index.
+        """
         super().__init__()
         self.index_name = index
         self.dims = dims
@@ -70,12 +101,15 @@ class Embedder:
             llm=OpenAI(temperature=0.7, cache=False), prompt=self.QUERY_TEMPLATE
         )
 
+    @retry(exceptions=RateLimitError, tries=5, delay=6, jitter=(0, 4))
     def _generate_query(self, fact: str, doc: Document) -> str:
         return self.query_chain.run(fact=fact, context=doc.metadata["summary"])
 
     def embed(
         self, doc: Document, gen_queries: bool = False
     ) -> Generator[Embedding, None, None]:
+        """Yields a set of embeddings for a given document."""
+
         for fact in doc.metadata["facts"]:
             yield self._embed(query=fact, fact=fact, doc=doc)
             if gen_queries:
@@ -87,6 +121,9 @@ class Embedder:
                     )
 
     def persist(self, doc: Document) -> list[Embedding]:
+        """Collects the set of embeddings for a Document,
+        and persists them to the vector store."""
+
         embeddings = list(self.embed(doc, gen_queries=True))
         vectors = [
             (
